hls2model for PEPRMT
Usage
hls2model.PEPRMT(
in.path,
in.prefix,
outfolder,
start_date,
end_date,
lat,
lon,
overwrite = FALSE,
verbose = FALSE,
...
)Arguments
- in.path
location on disk where inputs are stored
- in.prefix
prefix of input and output files
- outfolder
location on disk where outputs will be stored
- start_date, end_date
the start and end dates of the data to be downloaded (will only use the year part of the date)
- lat, lon
latitude and longitude in degrees
- overwrite
should existing files be overwritten
- verbose
should the function be very verbose
- ...
additional arguments, currently ignored